@@ -5,8 +5,8 @@
 ;; Author: Shen, Jen-Chieh <jcs090218@gmail.com>
 ;; Maintainer: Shen, Jen-Chieh <jcs090218@gmail.com>
 ;; URL: https://github.com/emacs-eask/easky
-;; Package-Version: 20251231.1607
-;; Package-Revision: efe25f0c1ba4
+;; Package-Version: 20260123.1934
+;; Package-Revision: 2eb06188d2a1
 ;; Package-Requires: ((emacs "27.1") (eask-mode "0.1.0") (eask "0.1.0") (ansi "0.4.1") (lv "0.0") (marquee-header "0.1.0"))
 ;; Keywords: maint easky
 
@@ -503,6 +503,17 @@ is the implementation."
           (call-interactively command)
         (user-error "Command %s not implemented yet, please consider report it to us!" command)))))
 
+;;;###autoload
+(defun easky-docs ()
+  "Build documentation."
+  (interactive)
+  (easky--exec-with-help
+      (easky-command "docs" "--help") 2 "Select `eask docs' command: "
+    (let ((command (intern (format "easky-docs-%s" command))))
+      (if (fboundp command)
+          (call-interactively command)
+        (user-error "Command %s not implemented yet, please consider report it to us!" command)))))
+
 ;;;###autoload
 (defun easky-generate ()
   "Start Eask generate."
@@ -869,11 +880,11 @@ This can be replaced with `easky-package-install' command."
 ;;; Documentation
 
 ;;;###autoload
-(defun easky-docs ()
-  "Build documentation."
+(defun easky-docs-el2org ()
+  "Build documentation with `el2org'."
   (interactive)
   (let ((pattern (read-string "Files: ")))
-    (easky--display (easky-command "docs" pattern))))
+    (easky--display (easky-command "docs" "el2org" pattern))))
 
 ;;
 ;;; Eask-file Checker
